
# Enum: PersonStatus




URI: [nwb_schema_language:PersonStatus](https://w3id.org/p2p_ld/nwb-schema-language/PersonStatus)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| ALIVE | the person is living | PATO:0001421 |  |
| DEAD | the person is deceased | PATO:0001422 |  |
| UNKNOWN | the vital status is not known |  | {'todos': ['map this to an ontology']} |

